@@ -2,7 +2,6 @@ import unittest
 from zope.testing import doctest
 
 from Testing import ZopeTestCase
-from Testing.ZopeTestCase.zopedoctest import functional
 from Products.PloneTestCase import ptc
 
 from collective.formcriteria import testing
@@ -11,16 +10,11 @@ optionflags = (doctest.NORMALIZE_WHITESPACE|
                doctest.ELLIPSIS|
                doctest.REPORT_NDIFF)
 
-orig_outstream_init = functional.DocResponseWrapper.__init__
-def outstream_init(self, response, outstream, path, header_output):
-    if not response.body:
-        response.body = outstream.getvalue()
-    orig_outstream_init(self, response, outstream, path,
-                        header_output)
-
 def test_suite():
     suite = ZopeTestCase.FunctionalDocFileSuite(
         'README.txt',
+        'foldercontents/README.txt',
+        'foldercontents/buttons.txt',
         optionflags=optionflags,
         test_class=ptc.FunctionalTestCase)
     suite.layer = testing.layer
